@@ -8,5 +8,5 @@
 
 from obstruction_detector_connector.shift_analyze_result import ObstructionAnalyzeResult
 from obstruction_detector_connector.shift_detector_connector import ObstructionDetectorConnector
-from detector_connector import DetectorHttpConnector as ShiftDetectorHttpConnector
+from detector_connector import DetectorHttpConnector as ObstructionDetectorHttpConnector
 from obstruction_detector_connector.shift_detector_kafka_connector import ObstructionDetectorKafkaConnector
